<?php
/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Social Login Hyva Compatibility
 */
declare(strict_types=1);

namespace Amasty\SocialLoginHyva\Controller\Ajax;

use Magento\Framework\App\Action\HttpGetActionInterface;
use Magento\Framework\App\View as AppView;
use Magento\Framework\Controller\Result\JsonFactory as ResultJsonFactory;
use Magento\Framework\Controller\Result\Json as ResultJson;
use Magento\Framework\Exception\NoSuchEntityException;

class ReviewForm implements HttpGetActionInterface
{
    /**
     * @var ResultJsonFactory
     */
    private ResultJsonFactory $resultJsonFactory;

    /**
     * @var AppView
     */
    private AppView $appView;

    /**
     * @param ResultJsonFactory $resultJsonFactory
     * @param AppView $appView
     */
    public function __construct(
        ResultJsonFactory $resultJsonFactory,
        AppView $appView
    ) {
        $this->resultJsonFactory = $resultJsonFactory;
        $this->appView = $appView;
    }

    /**
     * Return ajax response with review form
     *
     * @return ResultJson
     */
    public function execute(): ResultJson
    {
        $reviewFormHtml = '';
        $error = '';

        try {
            $this->appView->loadLayout('catalog_product_view');

            $layout = $this->appView->getLayout();
            if ($reviewBlock = $layout->getBlock('product.review.form')) {
                $reviewFormHtml = $reviewBlock->toHtml();
            }
        } catch (NoSuchEntityException $e) { // phpcs:ignore
            $error = $e->getMessage();
        }

        return $this->resultJsonFactory->create()
            ->setData([
                'form' => $reviewFormHtml,
                'error' => $error
            ]);
    }
}
