<?php
/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Social Login Hyva Compatibility
 */

declare(strict_types=1);

namespace Amasty\SocialLoginHyva\Controller\Header;

use Magento\Framework\App\Action\HttpGetActionInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\App\View as AppView;
use Magento\Framework\Controller\Result\JsonFactory as ResultJsonFactory;
use Magento\Framework\Controller\Result\Json as ResultJson;
use Magento\Framework\Controller\Result\RedirectFactory as ResultRedirectFactory;
use Magento\Framework\Controller\Result\Redirect as ResultRedirect;
use Magento\Framework\Exception\NoSuchEntityException;

class Update implements HttpGetActionInterface
{
    /**
     * @var ResultJsonFactory
     */
    private ResultJsonFactory $resultJsonFactory;

    /**
     * @var AppView
     */
    private AppView $appView;

    /**
     * @var ResultRedirectFactory
     */
    private ResultRedirectFactory $resultRedirectFactory;

    /**
     * @var RequestInterface
     */
    private RequestInterface $request;

    /**
     * @var string
     */
    private string $customerMenuBlockName;

    /**
     * @param ResultJsonFactory $resultJsonFactory
     * @param ResultRedirectFactory $resultRedirectFactory
     * @param AppView $appView
     * @param RequestInterface $request
     * @param string $customerMenuBlockName
     */
    public function __construct(
        ResultJsonFactory $resultJsonFactory,
        ResultRedirectFactory $resultRedirectFactory,
        AppView $appView,
        RequestInterface $request,
        string $customerMenuBlockName = 'header.customer'
    ) {
        $this->resultJsonFactory = $resultJsonFactory;
        $this->resultRedirectFactory = $resultRedirectFactory;
        $this->appView = $appView;
        $this->request = $request;
        $this->customerMenuBlockName = $customerMenuBlockName;
    }

    /**
     * Return ajax response with header content
     *
     * @return ResultJson|ResultRedirect
     */
    public function execute()
    {
        if ($this->request->isAjax()) {
            $resultPage = $this->resultJsonFactory->create();
            $resultPage->setHttpResponseCode(200);
            $resultPage->setData([
                'customer_menu_html'  => $this->getCustomerMenuHtml()
            ]);
            return $resultPage;
        } else {
            /** @var Redirect $resultRedirect */
            $resultRedirect = $this->resultRedirectFactory->create();
            $resultRedirect->setPath('/');
            return $resultRedirect;
        }
    }

    /**
     * Retrieve customer menu HTML
     *
     * @return string
     */
    private function getCustomerMenuHtml(): string
    {
        $customerMenuHtml = '';

        try {
            $this->appView->loadLayout('default');

            $layout = $this->appView->getLayout();
            if ($customerMenuBlock = $layout->getBlock($this->customerMenuBlockName)) {
                $customerMenuHtml = $customerMenuBlock->toHtml();
            }
        } catch (NoSuchEntityException $exception) { // phpcs:ignore
        }

        return $customerMenuHtml;
    }
}
