<?php
/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Social Login Hyva Compatibility
 */
declare(strict_types=1);

namespace Amasty\SocialLoginHyva\ViewModel;

use Amasty\SocialLogin\Model\ConfigData;
use Magento\Customer\Model\Context as CustomerContext;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Framework\App\Http\Context;

class Popup implements ArgumentInterface
{
    public const TAB_NAME_LOGIN        = 'amsl-login';
    public const TAB_NAME_REGISTER     = 'amsl-register';
    public const TAB_NAME_FORGOT       = 'amsl-forgot';
    public const NOTIFICATION_MODAL_ID = 'amsl-popup-notification';
    public const IS_GUEST_CHECKOUT_ALLOWED = 'checkout/options/guest_checkout';

    /**
     * Amasty configuration model
     *
     * @var ConfigData
     */
    private ConfigData $configData;

    /**
     * @var Context
     */
    private Context $httpContext;

    /**
     * @param ConfigData $configData
     * @param Context $httpContext
     */
    public function __construct(
        ConfigData $configData,
        Context $httpContext
    ) {
        $this->configData = $configData;
        $this->httpContext = $httpContext;
    }

    /**
     * Check if Ajax popup is enabled based on configuration entry
     *
     * @return bool
     */
    public function isPopupEnabled(): bool
    {
        return $this->configData->isPopupEnabled();
    }

    /**
     * Check if ajax popup or notification modal can be closed by clicking on overlay
     *
     * @return bool
     */
    public function shouldCloseOnOverlayClick(): bool
    {
        return $this->configData->isCloseWhenClickedOutside();
    }

    /**
     * Check if user logged in
     *
     * @return bool
     */
    public function isCustomerLoggedIn(): bool
    {
        return $this->httpContext->getValue(CustomerContext::CONTEXT_AUTH) ? true : false;
    }
}
