<?php
/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Social Login Hyva Compatibility
 */
declare(strict_types=1);

namespace Amasty\SocialLoginHyva\ViewModel\Popup;

use Amasty\SocialLoginHyva\ViewModel\Popup;
use Magento\Framework\Serialize\SerializerInterface;
use Magento\Framework\View\Element\Block\ArgumentInterface;

class Forms implements ArgumentInterface
{
    /**
     * Can be customized via di.xml
     */
    private const DEFAULT_CONFIG = [
        Popup::TAB_NAME_LOGIN => [
            'formType' => Popup::TAB_NAME_LOGIN,
            'formId' => 'customer-login-form',
            'successMessage' => 'You have successfully logged in.',
            'submitUrlReplacement' => 'amsociallogin/account'
        ],
        Popup::TAB_NAME_REGISTER => [
            'formType' => Popup::TAB_NAME_REGISTER,
            'formId' => 'accountcreate',
            'successMessage' => 'Thank you for registering with us.',
            'submitUrlReplacement' => 'amsociallogin/account'
        ],
        Popup::TAB_NAME_FORGOT => [
            'formType' => Popup::TAB_NAME_FORGOT,
            'formId' => 'user_forgotpassword',
            'customSubmitUrl' => '/customer/account/forgotpasswordpost'
        ]
    ];
    /**
     * JSON serializer
     *
     * @var SerializerInterface
     */
    private SerializerInterface $serializer;

    /**
     * Configuration for forms in authentication popup
     *
     * @var array
     */
    private array $formsConfig = [];

    /**
     * @param SerializerInterface $serializer
     * @param array $formsConfig
     */
    public function __construct(
        SerializerInterface $serializer,
        array $formsConfig = []
    ) {
        $this->serializer = $serializer;
        $this->formsConfig = $this->prepareFormsConfig(array_merge_recursive(self::DEFAULT_CONFIG, $formsConfig));
    }

    /**
     * Retrieve forms configuration in JSON format
     *
     * @return string
     */
    public function getFormsConfigJson(): string
    {
        return $this->serializer->serialize($this->formsConfig);
    }

    /**
     * Prepare form configuration entries, which depend on storefront
     *
     * @param array $config
     * @return array
     */
    private function prepareFormsConfig(array $config): array
    {
        return $this->translateMessages($config);
    }

    /**
     * Translate messages in forms configuration
     *
     * @param array $config
     * @return array
     */
    private function translateMessages(array $config): array
    {
        foreach ($config as $formType => $formOptions) {
            if (isset($formOptions['successMessage'])) {
                $config[$formType]['successMessage'] = (string) __($formOptions['successMessage']);
            }
        }

        return $config;
    }
}
